@@ -14,7 +14,8 @@ def create_key(days, level, amount):
         level = 1
     if amount == None:
         amount=1
-        add = requests.get(f"https://keyauth.com/api/seller/?sellerkey={sellerkey2}&type=add&expiry={days}&mask=XXXXXX-XXXXXX-XXXXXX-XXXXXX-XXXXXX-XXXXXX&level={level}&amount={amount}&format=json")
-        addjson = json.load(add)
-        if add.status_code == 200:
-            return addjson[2]
\ No newline at end of file
+        req = requests.get(f"https://keyauth.com/api/seller/?sellerkey={sellerkey2}&type=add&expiry={days}&mask=XXXXXX-XXXXXX-XXXXXX-XXXXXX-XXXXXX-XXXXXX&level={level}&amount={amount}&format=json")
+        reqj = req.json()
+        key = reqj['key']
+        if reqj['success'] == True:
+            return reqj['key']
\ No newline at end of file
